"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var electron_1 = require("electron");
var path = require("path");
var config = require("../js/config");
var environment_1 = require("../js/environment");
var lifecycle = require("../js/lifecycle");
var windowManager = require("../js/window-manager");
var locale = require("../locale/locale");
var TrayHandler = (function () {
    function TrayHandler() {
        this.lastUnreadCount = 0;
    }
    TrayHandler.prototype.initTray = function (trayIcon) {
        if (trayIcon === void 0) { trayIcon = new electron_1.Tray(electron_1.nativeImage.createEmpty()); }
        var IMAGE_ROOT = path.join(electron_1.app.getAppPath(), 'img');
        var trayPng = 'tray.png';
        var trayBadgePng = 'tray.badge.png';
        if (environment_1.platform.IS_LINUX) {
            trayPng = "tray" + (environment_1.linuxDesktop.isGnome ? '.gnome' : '@3x') + ".png";
            trayBadgePng = "tray.badge" + (environment_1.linuxDesktop.isGnome ? '.gnome' : '@3x') + ".png";
        }
        var iconPaths = {
            badge: path.join(IMAGE_ROOT, 'taskbar.overlay.png'),
            tray: path.join(IMAGE_ROOT, 'tray-icon', 'tray', trayPng),
            trayWithBadge: path.join(IMAGE_ROOT, 'tray-icon', 'tray-with-badge', trayBadgePng),
        };
        this.icons = {
            badge: electron_1.nativeImage.createFromPath(iconPaths.badge),
            tray: electron_1.nativeImage.createFromPath(iconPaths.tray),
            trayWithBadge: electron_1.nativeImage.createFromPath(iconPaths.trayWithBadge),
        };
        this.trayIcon = trayIcon;
        this.trayIcon.setImage(this.icons.tray);
        this.buildTrayMenu();
    };
    TrayHandler.prototype.showUnreadCount = function (win, count) {
        this.updateIcons(win, count);
        this.flashApplicationWindow(win, count);
        this.updateBadgeCount(count);
    };
    TrayHandler.prototype.buildTrayMenu = function () {
        var _this = this;
        var contextMenu = electron_1.Menu.buildFromTemplate([
            {
                click: function () { return windowManager.showPrimaryWindow(); },
                label: locale.getText('trayOpen'),
            },
            {
                click: function () { return __awaiter(_this, void 0, void 0, function () { return __generator(this, function (_a) {
                    return [2, lifecycle.quit()];
                }); }); },
                label: locale.getText('trayQuit'),
            },
        ]);
        if (this.trayIcon) {
            this.trayIcon.on('click', function () { return windowManager.showPrimaryWindow(); });
            this.trayIcon.setContextMenu(contextMenu);
            this.trayIcon.setToolTip(config.NAME);
        }
    };
    TrayHandler.prototype.flashApplicationWindow = function (win, count) {
        if (win.isFocused() || !count) {
            win.flashFrame(false);
        }
        else if (count > this.lastUnreadCount) {
            win.flashFrame(true);
        }
    };
    TrayHandler.prototype.updateBadgeCount = function (count) {
        if (typeof count !== 'undefined') {
            electron_1.app.setBadgeCount(count);
            this.lastUnreadCount = count;
        }
    };
    TrayHandler.prototype.updateIcons = function (win, count) {
        if (this.icons) {
            var trayImage = count ? this.icons.trayWithBadge : this.icons.tray;
            if (this.trayIcon) {
                this.trayIcon.setImage(trayImage);
            }
            var overlayImage = count ? this.icons.badge : null;
            win.setOverlayIcon(overlayImage, locale.getText('unreadMessages'));
        }
    };
    return TrayHandler;
}());
exports.TrayHandler = TrayHandler;
//# sourceMappingURL=TrayHandler.js.map